/*
 * text_renderer.h
 *
 * Copyright (C) 2011 Tim Marston <tim@ed.am> and Dan Marston.
 *
 * This file is part of propeller-clock (hereafter referred to as "this
 * program"). See http://ed.am/dev/software/arduino/propeller-clock for more
 * information.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#ifndef _TEXT_RENDERER_H_
#define _TEXT_RENDERER_H_


#include <PString.h>


#define MESSAGE_BUFFER_LEN 32


namespace TextRenderer
{

	/**
	 * Get the width, in pexels, of a message.
	 *
	 * @param message_len the length of the message
	 */
	int get_width( int message_len );

	/**
	 * Draw a column of pixels at pixel-offset x in the message.
	 *
	 * @param message the message
	 * @param message_len the length of the message (to save it being
	 * 		calculated)
	 * @param x the pixel column of the message to draw
	 * @param y_flip true to draw up-side down
	 * @param y_shift shift the drawing up/down
	 */
	void render( const char *message, int message_len, int x,
				 bool y_flip, int y_shift );

	/**
	 * Reset the output buffer.
	 */
	void reset_buffer();

	/**
	 * Output the output buffer (and reset the output buffer).
	 */
	void output_buffer();

	/**
	 * Set the font number to use
	 *
	 * @param font_num font number
	 */
	void select_font( int font_num );

};


#endif //_TEXT_RENDERER_H_
